Key Management Service (KMS)
============================

The KMS client is the command-line interface (CLI) for
the Key Management service (KMS) API and its extensions.

For help on a specific `kms` command, enter:

.. code-block:: console

   $ openstack kms help SUBCOMMAND

.. _cmk:

CMK operations
--------------

.. autoprogram-cliff:: openstack.kms.v1
   :command: kms cmk *
